]> git.immae.eu Git - github/Chocobozzz/PeerTube.git/blobdiff - server.js
Remove Node 4 support
[github/Chocobozzz/PeerTube.git] / server.js
index 63aeb7145959348f3e406cae86cfa70132616e58..33d399786da00edd0f787ee8cba3b7819ed09ba9 100644 (file)
--- a/server.js
+++ b/server.js
@@ -10,34 +10,37 @@ const path = require('path')
 const TrackerServer = require('bittorrent-tracker').Server
 const WebSocketServer = require('ws').Server
 
+process.title = 'peertube'
+
 // Create our main app
 const app = express()
 
+// ----------- Database -----------
+const constants = require('./server/initializers/constants')
+const logger = require('./server/helpers/logger')
+// Initialize database and models
+const db = require('./server/initializers/database')
+db.init(onDatabaseInitDone)
+
 // ----------- Checker -----------
 const checker = require('./server/initializers/checker')
 
-const miss = checker.checkConfig()
-if (miss.length !== 0) {
-  throw new Error('Miss some configurations keys : ' + miss)
+const missed = checker.checkMissedConfig()
+if (missed.length !== 0) {
+  throw new Error('Miss some configurations keys : ' + missed)
+}
+
+const errorMessage = checker.checkConfig()
+if (errorMessage !== null) {
+  throw new Error(errorMessage)
 }
 
 // ----------- PeerTube modules -----------
-const config = require('config')
-const constants = require('./server/initializers/constants')
-const customValidators = require('./server/helpers/customValidators')
-const database = require('./server/initializers/database')
+const customValidators = require('./server/helpers/custom-validators')
+const friends = require('./server/lib/friends')
 const installer = require('./server/initializers/installer')
-const logger = require('./server/helpers/logger')
-const poolRequests = require('./server/lib/requestsScheduler')
+const migrator = require('./server/initializers/migrator')
 const routes = require('./server/controllers')
-const utils = require('./server/helpers/utils')
-const webtorrent = require('./server/lib/webtorrent')
-
-// Get configurations
-const port = config.get('listen.port')
-
-// ----------- Database -----------
-database.connect()
 
 // ----------- Command line -----------
 
@@ -46,36 +49,35 @@ database.connect()
 // For the logger
 app.use(morgan('combined', { stream: logger.stream }))
 // For body requests
-app.use(bodyParser.json())
+app.use(bodyParser.json({ limit: '500kb' }))
 app.use(bodyParser.urlencoded({ extended: false }))
 // Validate some params for the API
 app.use(expressValidator({
-  customValidators: customValidators
+  customValidators: Object.assign(
+    {},
+    customValidators.misc,
+    customValidators.pods,
+    customValidators.users,
+    customValidators.videos,
+    customValidators.remote.videos
+  )
 }))
 
 // ----------- Views, routes and static files -----------
 
-// Catch sefaults
-require('segfault-handler').registerHandler()
-
-// API routes
+// API
 const apiRoute = '/api/' + constants.API_VERSION
 app.use(apiRoute, routes.api)
 
-// Static files
-app.use('/client', express.static(path.join(__dirname, '/client/dist'), { maxAge: 0 }))
-// 404 for static files not found
-app.use('/client/*', function (req, res, next) {
-  res.sendStatus(404)
-})
+// Client files
+app.use('/', routes.client)
 
-// Thumbnails path for express
-const thumbnailsPhysicalPath = path.join(__dirname, config.get('storage.thumbnails'))
-app.use(constants.THUMBNAILS_STATIC_PATH, express.static(thumbnailsPhysicalPath, { maxAge: 0 }))
+// Static files
+app.use('/', routes.static)
 
-// Client application
+// Always serve index client page (the client is a single page application, let it handle routing)
 app.use('/*', function (req, res, next) {
-  res.sendFile(path.join(__dirname, 'client/dist/index.html'))
+  res.sendFile(path.join(__dirname, './client/dist/index.html'))
 })
 
 // ----------- Tracker -----------
@@ -115,35 +117,29 @@ app.use(function (err, req, res, next) {
   res.sendStatus(err.status || 500)
 })
 
-installer.installApplication(function (err) {
-  if (err) throw err
-
-  // Create/activate the webtorrent module
-  webtorrent.create(function () {
-    function cleanForExit () {
-      utils.cleanForExit(webtorrent.app)
-    }
+// ----------- Run -----------
 
-    function exitGracefullyOnSignal () {
-      process.exit(-1)
-    }
+function onDatabaseInitDone () {
+  const port = constants.CONFIG.LISTEN.PORT
+    // Run the migration scripts if needed
+  migrator.migrate(function (err) {
+    if (err) throw err
 
-    process.on('exit', cleanForExit)
-    process.on('SIGINT', exitGracefullyOnSignal)
-    process.on('SIGTERM', exitGracefullyOnSignal)
+    installer.installApplication(function (err) {
+      if (err) throw err
 
-    // ----------- Make the server listening -----------
-    server.listen(port, function () {
-      // Activate the pool requests
-      poolRequests.activate()
+      // ----------- Make the server listening -----------
+      server.listen(port, function () {
+        // Activate the communication with friends
+        friends.activate()
 
-      // videos.seedAllExisting(function () {
-        logger.info('Seeded all the videos')
         logger.info('Server listening on port %d', port)
+        logger.info('Webserver: %s', constants.CONFIG.WEBSERVER.URL)
+
         app.emit('ready')
-      // })
+      })
     })
   })
-})
+}
 
 module.exports = app